package routers

import (
	"spaceofcheng/services/controllers"
	"spaceofcheng/services/controllers/cases"
	"spaceofcheng/services/controllers/customer"
	"spaceofcheng/services/controllers/goods"
	"spaceofcheng/services/controllers/message"
	"spaceofcheng/services/controllers/system"
	"spaceofcheng/services/controllers/user"

	"github.com/astaxie/beego"
)

func getCommonRoutes() beego.LinkNamespace {
	prefix := beego.AppConfig.String("api::common")

	return beego.NSNamespace(prefix,
		// 商品分类
		beego.NSRouter("/type/goods", &goods.GoodsController{}, "get:GetGoodsType"),
		beego.NSRouter("/type/goods/:typeid", &goods.GoodsController{}, "get:GetGoodsTypeByID"),
		beego.NSRouter("/type/goods", &goods.GoodsController{}, "post:SaveGoodsType"),
		beego.NSRouter("/type/goods/:typeid", &goods.GoodsController{}, "put:SaveGoodsType"),
		beego.NSRouter("/type/goods/:typeid", &goods.GoodsController{}, "delete:DelGoodsType"),

		// 商品规格
		beego.NSRouter("/spec/goods", &goods.GoodsController{}, "get:GetGoodsSpec"),
		beego.NSRouter("/spec/goods/:specid", &goods.GoodsController{}, "get:GetGoodsSpecByID"),
		beego.NSRouter("/spec/goods", &goods.GoodsController{}, "post:SaveGoodsSpec"),
		beego.NSRouter("/spec/goods/:specid", &goods.GoodsController{}, "put:SaveGoodsSpec"),
		beego.NSRouter("/spec/goods/:specid", &goods.GoodsController{}, "delete:DelGoodsSpec"),

		// 系统用户
		beego.NSRouter("/user", &user.UserController{}, "get:GetUserList"),
		beego.NSRouter("/user/:userid", &user.UserController{}, "get:GetUserByID"),
		beego.NSRouter("/user/:userid/password", &user.UserController{}, "put:UpdatePassword"),
		beego.NSRouter("/user/password/reset", &user.UserController{}, "put:ResetPassword"),
		beego.NSRouter("/signout", &user.UserController{}, "post:SignOut"),

		// cms 位置
		beego.NSRouter("/cms/location", &message.MessageController{}, "get:GetLocations"),
		beego.NSRouter("/cms/location/:locationid", &message.MessageController{}, "get:GetLocationById"),
		beego.NSRouter("/cms/location", &message.MessageController{}, "post:SaveLocation"),
		beego.NSRouter("/cms/location/:locationid", &message.MessageController{}, "put:SaveLocation"),
		beego.NSRouter("/cms/location/:locationid", &message.MessageController{}, "delete:DelLocation"),

		// cms
		beego.NSRouter("/cms/info", &message.MessageController{}, "get:GetCmsInfoList"),
		beego.NSRouter("/cms/info/:infoid", &message.MessageController{}, "get:GetCmsInfoByID"),
		beego.NSRouter("/cms/info", &message.MessageController{}, "post:SaveCmsInfo"),
		beego.NSRouter("/cms/info/:infoid", &message.MessageController{}, "put:SaveCmsInfo"),
		beego.NSRouter("/cms/info/:infoid", &message.MessageController{}, "delete:DelCmsInfo"),

		// cms 图片
		beego.NSRouter("/cms/image", &message.MessageController{}, "get:GetImgList"),
		beego.NSRouter("/cms/image/:imgid", &message.MessageController{}, "get:GetImgByID"),
		beego.NSRouter("/cms/image", &message.MessageController{}, "post:SaveImage"),
		beego.NSRouter("/cms/image/:imgid", &message.MessageController{}, "put:SaveImage"),
		beego.NSRouter("/cms/image/:imgid", &message.MessageController{}, "delete:DelImg"),

		// cms 消息
		beego.NSRouter("/cms/news", &message.MessageController{}, "get:GetNews"),
		beego.NSRouter("/cms/news/:newsid", &message.MessageController{}, "get:GetNewsByID"),
		beego.NSRouter("/cms/news", &message.MessageController{}, "post:SaveNews"),
		beego.NSRouter("/cms/news/:newsid", &message.MessageController{}, "put:SaveNews"),
		beego.NSRouter("/cms/news/:newsid", &message.MessageController{}, "delete:DelNews"),

		// cms 案场
		beego.NSRouter("/cms/case", &message.MessageController{}, "get:GetCmsCase"),
		beego.NSRouter("/cms/case/:cmscaseid", &message.MessageController{}, "get:GetCmsCaseByID"),
		beego.NSRouter("/cms/case", &message.MessageController{}, "post:SaveCmsCase"),
		beego.NSRouter("/cms/case/:cmscaseid", &message.MessageController{}, "put:SaveCmsCase"),
		beego.NSRouter("/cms/case/:cmscaseid", &message.MessageController{}, "delete:DelCmsCase"),

		beego.NSRouter("/caseuser", &cases.CaseController{}, "get:GetCaseUserByCase"),
		beego.NSRouter("/caseuserbytype", &cases.CaseController{}, "get:GetCaseUserByType"),
		beego.NSRouter("/caseuser/:userid", &cases.CaseController{}, "get:GetCaseUserByID"),
		beego.NSRouter("/caseuser", &cases.CaseController{}, "post:SaveCaseUser"),
		beego.NSRouter("/caseuser", &cases.CaseController{}, "put:SaveCaseUser"),
		beego.NSRouter("/caseuser/:userid", &cases.CaseController{}, "delete:DelCaseUser"),

		beego.NSRouter("/equipment", &cases.CaseController{}, "get:GetEquipmentList"),
		beego.NSRouter("/equipment/:id", &cases.CaseController{}, "get:GetEquipmentByID"),
		beego.NSRouter("/equipment", &cases.CaseController{}, "post:SaveCaseEquipment"),
		beego.NSRouter("/equipment", &cases.CaseController{}, "put:SaveCaseEquipment"),
		beego.NSRouter("/equipment/:id", &cases.CaseController{}, "delete:DelCaseEquipment"),

		beego.NSRouter("/case", &cases.CaseController{}, "get:GetCaseList"),
		beego.NSRouter("/case/:id", &cases.CaseController{}, "get:GetCaseByID"),
		beego.NSRouter("/case", &cases.CaseController{}, "post:SaveCase"),
		beego.NSRouter("/case", &cases.CaseController{}, "put:SaveCase"),
		beego.NSRouter("/case/:id", &cases.CaseController{}, "delete:DelCase"),

		beego.NSRouter("/casekey", &cases.CaseController{}, "get:GetKeyList"),
		beego.NSRouter("/casekey", &cases.CaseController{}, "post:AddKeys"),
		beego.NSRouter("/caseunlock/:keyid", &cases.CaseController{}, "put:UnLockKey"),
		beego.NSRouter("/casekey/:id", &cases.CaseController{}, "delete:DelKey"),

		beego.NSRouter("/casearea", &cases.CaseController{}, "get:GetCaseArea"),
		beego.NSRouter("/casearea/:areaid", &cases.CaseController{}, "get:GetCaseAreaByID"),
		beego.NSRouter("/casearea", &cases.CaseController{}, "post:SaveCaseArea"),
		beego.NSRouter("/casearea", &cases.CaseController{}, "put:SaveCaseArea"),
		beego.NSRouter("/casearea/:areaid", &cases.CaseController{}, "delete:DelCaseArea"),

		beego.NSRouter("/casetable", &cases.CaseController{}, "get:GetCaseTable"),
		beego.NSRouter("/casetable/:tableid", &cases.CaseController{}, "get:GetCaseTableByID"),
		beego.NSRouter("/casetable", &cases.CaseController{}, "post:SaveCaseTable"),
		beego.NSRouter("/casetable", &cases.CaseController{}, "put:SaveCaseTable"),
		beego.NSRouter("/casetable/:tableid", &cases.CaseController{}, "delete:DelCaseTable"),

		beego.NSRouter("/role", &system.RoleController{}, "get:GetRoleList"),
		beego.NSRouter("/role/:roleid", &system.RoleController{}, "get:GetRoleByID"),
		beego.NSRouter("/role", &system.RoleController{}, "post:SaveCaseRole"),
		beego.NSRouter("/role", &system.RoleController{}, "put:SaveCaseRole"),
		beego.NSRouter("/role/:roleid", &system.RoleController{}, "delete:DelCaseRole"),

		// 文件
		beego.NSRouter("/file", &controllers.BaseController{}, "post:FileUpload"),

		// 会员
		beego.NSRouter("/customer", &customer.CustomerController{}, "get:CustWXList"),

		// 系统相关
		beego.NSRouter("/system/init", &user.UserController{}, "get:GetEnvVars"),
	)
}
